@@ -13,14 +13,15 @@ installation:
 
 setup: 
 
-- Add a mouse gesture for "pyrad.py": go into KDE systemsettings -> keyboard shortcuts -> add a gesture with the action "pyrad.py" (you might have to enable gestures in the settings, too - in the shortcuts-window you should find a settings button).
-- customize the menu by editing the file "~/.pyradrc" or right-clicking items.
+- Add "/usr/bin/pyrad.py" as script to your autostart (systemsettings->advanced->autostart) TODO: make it not show the GUI.
+- Run "/usr/bin/pyrad.py" to see it in your current session. 
+- You can now call it with Alt-F6 or Meta-F6.
 
-Alternate setup with dbus (much faster but incomplete): 
+set a mouse gesture: 
 
-- Add "/usr/bin/pyrad.py" as script to your autostart (systemsettings->advanced->autostart) TODO: make it not show the GUI
 - Add the mouse gesture to call D-Bus: Program: org.kde.pyRad ; Object: /MainApplication ; Function: newInstance
 - Alternately set the gesture to call the command "dbus-send --type=method_call --dest=org.kde.pyRad /MainApplication org.kde.KUniqueApplication.newInstance"
+- customize the menu by editing the file "~/.pyradrc" or right- and middle-clicking items.
 
 """
 
@@ -32,8 +33,7 @@ usage:
 - Use your gesture to call up the command wheel when you want to call one of your included programs.
 - Left-click the program to start it. You can also press the key shown in the programs tooltip for the same effect. 
 - Right-click an item to edit it. Middle-click an item to add a new one after it (clockwise).
-- Make folders by using the action [("kreversi", None), ("icon", "action"), ("icon2", "action2"), ...].
-  Actions are simply the commands you'd use on the commandline (there's no shell scripting though, except via `bash -c "for i in 1 2 3; do echo $i; done"`).
+- Make folders by clicking on the folder button and saving the item.Remove items by clicking on the delete button and saving the item. Actions are simply the commands you'd use on the commandline (there's no shell scripting though, except via `bash -c "for i in 1 2 3; do echo $i; done"`).
 
 """
 
@@ -42,14 +42,14 @@ plan:
 
 - new command scheme: right-click always edits, middle-click adds a new item. -done
 - items arranged clockwise. -done
+- Edit dialog should show the icon graphically. A click on the item should show the edit dialog we have when editing the K-Menu. -done
+- Edit dialog should have a radio button for the action: "create folder". -done
+- register a global shortcut / gesture in KDE from within the program -> usable as soon as it's installed. -partial (keyboard)
+- make it show faster. -done
+- add option --only-daemon to only start the daemon without showing the GUI -done
 - right-click on center opens a general config dialog. -todo
 - a general config dialog. -todo
 - first run of new version shows image as usage guide. -todo
-- Edit dialog should show the icon graphically. A click on the item should show the edit dialog we have when editing the K-Menu. -todo
-- Edit dialog should have a radio button for the action: "create folder". -todo
-- register a global shortcut / gesture in KDE from within the program -> usable as soon as it's installed. -todo
-- make it show faster. -todo
-- add option --only-daemon to only start the daemon without showing the GUI
 """
 __ideas__ = """
 ideas:
@@ -62,16 +62,16 @@ ideas:
 - Adjust circle radius to the number of icons. 
 - Show the icons inside a folder over/around the folder icon. 
 - Add a CLI fallback, so people can also access their actions via the shell. 
-- Talk to DBus directly (for higher performance). -> dbus-send --type=method_call --dest=org.kde.pyRad /MainApplication org.kde.KUniqueApplication.newInstance
-  (from http://www.staerk.de/thorsten/index.php/Hacking_KDE)
-- Keyboard shortcuts (1, 2, 3, ... for the wheel items -> click paths to programs)
 - Check if an app is already open. If it is, simply switch to it (dbus -> get winID, forceActivateWindow(winID)?). 
   Sample DBus calls: dbus-send --dest=org.freedesktop.DBus --type=method_call --print-reply / org.freedesktop.DBus.ListNames ; dbus-send --dest=org.kde.konqueror-14040 --type=method_call --print-reply /konqueror/MainWindow_1 org.kde.KMainWindow.winId; dbus-send --dest=org.freedesktop.DBus --type=method_call --print-reply / org.freedesktop.DBus.NameHasOwner string:"org.kde.pyRad"
   To bring a background app to foreground, hide its main window, then show it again.
   -> /konqueror com.trolltech.Qt.QWidget.hide + ...show + hide pyRad
   PID stuff: http://code.google.com/p/psutil/
+- Talk to DBus directly (for higher performance). -> dbus-send --type=method_call --dest=org.kde.pyRad /MainApplication org.kde.KUniqueApplication.newInstance
+  (from http://www.staerk.de/thorsten/index.php/Hacking_KDE) -done, left here for reference to the site.
 
 PyPI url: http://pypi.python.org/pypi/pyRadKDE
+Website: http://draketo.de/light/english/pyrad
 """
 
 __doc__ += __install__ + __usage__ + __plans__ + __ideas__
@@ -99,7 +99,7 @@ __copyright__ = """pyRad - a wheel type command menu.
 ### Constants ###
 
 #: The PyRad version identifier
-__version__ = "0.4.3"
+__version__ = "0.4.4"
 appName = "pyRad"
 
 ### Commandline handling ###
@@ -128,6 +128,9 @@ from PyKDE4.kdecore import ki18n, KAboutData
 # KApplication for basics
 from PyKDE4.kdeui import KUniqueApplication
 
+# SIGNALs and SLOTs for a clean shutdown. 
+from PyQt4.QtCore import SIGNAL, SLOT
+
 # and exiting.
 from sys import exit as exit_
 
@@ -142,6 +145,12 @@ class KUniqueCaller(KUniqueApplication):
         # And get and show the GUI
         Rad = importRad()
         self.rad = Rad()
+        self.connect(self, SIGNAL("shutDown()"), self.close)
+        self.connect(self, SIGNAL("shutDown()"), self.quit)
+
+    def close(self):
+        """Slot for closing the rad."""
+        self.rad.close()
 
     def newInstance(self):
         """Get a new instance -> in reality only check if there's already an instance and tell the GUI to run."""
