@@ -20,16 +20,18 @@ from os.path import join, isfile
 from user import home
 
 # basic graphical stuff
-from PyQt4.QtGui import QWidget, QGridLayout, QCursor, QIcon, QLabel, QLineEdit
+from PyQt4.QtGui import QWidget, QGridLayout, QCursor, QIcon, QLabel, QLineEdit, QPushButton, QKeySequence, QPolygon
 # basic definitions and datatypes
-from PyQt4.QtCore import Qt, QPointF, SIGNAL, SLOT
+from PyQt4.QtCore import Qt, QPointF, QPoint, SIGNAL, SLOT
 
 # Basics for KDE integration
-from PyKDE4.kdeui import KIconLoader
+from PyKDE4.kdeui import KIconLoader, KAction, KActionCollection, KShortcut, KShapeGesture
 # And a basic dialog class for the edit item dialog.
 from PyKDE4.kdeui import KDialog
 # also the KWindowSystem, so we can get ourselves to the foreground
 from PyKDE4.kdeui import KWindowSystem
+# and internationalization
+from PyKDE4.kdecore import i18n
 
 
 ### Constants ###
@@ -59,24 +61,59 @@ MAX_TOOL_TIP_LENGTH = 100
 ### Window ###
 
 class ItemEditWidget(QWidget):
-    def __init__(self, parent=None, icon="", action=None):
+    def __init__(self, parent=None, icon="konqueror", action=None):
         QWidget.__init__(self, parent)
         # First add a Layout
         self.lay = QGridLayout()
         self.setLayout(self.lay)
         # Now add a description text
         self.description = QLabel("Edit the icon (KDE progam name) and the action (commandline input). To delete the item, just delete the action line (set to empty).")
-        self.lay.addWidget(self.description, 0, 0, 1, 2)
-        # Then add a text field with name
+        self.lay.addWidget(self.description, 0, 0, 1, 3)
+        # Then add a text field with name        
         self.icon_label = QLabel("Icon:", self)
         self.icon_edit = QLineEdit(self)
+
+        # and the icon, updated live
+        self.iconloader = KIconLoader()
+        #self.icon = QPushButton(self) # for a button
+        self.icon = QLabel(self)
+        self.icon.icon = icon
+        self.icon.action = action
+
         self.lay.addWidget(self.icon_label, 1, 0)
-        self.lay.addWidget(self.icon_edit, 1, 1)
+        self.lay.addWidget(self.icon_edit, 1, 1, 1, 2)
+        self.lay.addWidget(self.icon, 1, 3)
         # Also add the same for the action
         self.action_label = QLabel("Action:", self)
         self.action_edit = QLineEdit(self)
+        self.action_new_folder = QPushButton("folder", self)
+        self.action_delete = QPushButton("delete", self)
         self.lay.addWidget(self.action_label, 2, 0)
         self.lay.addWidget(self.action_edit, 2, 1)
+        self.lay.addWidget(self.action_new_folder, 2, 2)
+        self.lay.addWidget(self.action_delete, 2, 3)
+
+        # make the icon update automatically
+        self.icon_edit.connect(self.icon_edit, SIGNAL("textChanged(QString)"), self.reload_icon)
+        # action buttons
+        self.action_new_folder.connect(self.action_new_folder, SIGNAL("clicked()"), self.action_to_folder)
+        self.action_delete.connect(self.action_delete, SIGNAL("clicked()"), self.action_empty)
+        
+    def reload_icon(self, name):
+        """reload the icon from the new name"""
+        self.icon.icon = name
+        #ic = QIcon(self.iconloader.loadIcon(name, 0)) # for a QPushButten
+        #self.icon.setIcon(ic)
+        self.icon.setPixmap(self.iconloader.loadIcon(name, 0))
+
+    def action_to_folder(self):
+        """turn the action into an empty folder"""
+        self.action_edit.setText("[('kreversi', None)]")
+
+    def action_empty(self):
+        """turn the action into an empty folder"""
+        self.action_edit.setText("")
+        
 
 # First we need a message box for editing the entries
 class ItemEditor(KDialog):
@@ -137,8 +174,33 @@ class Rad(QWidget):
         # Add a circle-list for all items
         self.circle = []
 
+        # add a shortcut to show the Rad.
+        self.showAction = KActionCollection(self).addAction("show")
+        self.showAction.setHelpText(i18n("Show the PyRad"))
+        short = self.showAction.shortcut()
+        short.setPrimary(QKeySequence(Qt.ALT + Qt.Key_F6))
+        short.setAlternate(QKeySequence(Qt.META + Qt.Key_F6))
+        self.showAction.setShortcut(short)
+        self.showAction.setGlobalShortcut(short)
+        # p0 = QPoint(9,3)
+        # p1 = QPoint(0,0)
+        # poly = QPolygon()
+        # poly.append(p0)
+        # poly.append(p1)
+        # reload_gesture = "0,0.0625,-0.5,0.5,1,0.0625,0.0625,-0.5,0.5,0.875,0.125,0.0625,-0.5,0.5,0.75,0.1875,0.0625,-0.5,0.5,0.625,0.25,0.0625,-0.5,0.5,0.5,0.3125,0.0625,-0.5,0.5,0.375,0.375,0.0625,-0.5,0.5,0.25,0.4375,0.0625,-0.5,0.5,0.125,0.5,0.0625,0.5,0.5,0,0.5625,0.0625,0.5,0.5,0.125,0.625,0.0625,0.5,0.5,0.25,0.6875,0.0625,0.5,0.5,0.375,0.75,0.0625,0.5,0.5,0.5,0.8125,0.0625,0.5,0.5,0.625,0.875,0.0625,0.5,0.5,0.75,0.9375,0.0625,0.5,0.5,0.875,1,0,0,0.5,1"
+        # gest = KShapeGesture(reload_gesture)
+        # gest.setShapeName("line, 1 right, 1/3rd up")
+        # self.showAction.setShapeGesture(gest)
+        # print self.showAction.shapeGesture().toString()
+        self.showAction.connect(self.showAction, SIGNAL("triggered(Qt::MouseButtons, Qt::KeyboardModifiers)"), self.showByShortcut)
+
         # Setup the circle - TODO: Call it via KUniqueApplication.newInstance
+        #self.setup()
+
+    def showByShortcut(self, mouseButtons=None, KeyboardModifiers=None):
         self.setup()
+        self.show()
+        self.toForeground()
 
     def toForeground(self):
         """Get into the foreground, so the user can click us."""
